@@ -1,7 +1,7 @@
 #
 # This file is part of MooseX-AttributeShortcuts
 #
-# This software is Copyright (c) 2011 by Chris Weyl.
+# This software is Copyright (c) 2017, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 #
 # This is free software, licensed under:
 #
@@ -9,8 +9,8 @@
 #
 package MooseX::AttributeShortcuts;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.027_02-0-g8e66785
-$MooseX::AttributeShortcuts::VERSION = '0.028';
+# git description: 0.028-45-g3997c3b
+$MooseX::AttributeShortcuts::VERSION = '0.029';
 
 # ABSTRACT: Shorthand for common attribute options
 
@@ -28,8 +28,8 @@ use Moose::Util::TypeConstraints;
 {
     package MooseX::AttributeShortcuts::Trait::Attribute;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.027_02-0-g8e66785
-$MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
+# git description: 0.028-45-g3997c3b
+$MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.029';
     use namespace::autoclean;
     use MooseX::Role::Parameterized;
     use Moose::Util::TypeConstraints  ':all';
@@ -38,12 +38,7 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
 
     use aliased 'MooseX::Meta::TypeConstraint::Mooish' => 'MooishTC';
 
-    use List::AllUtils 'any';
-
-    use Package::DeprecationManager -deprecations => {
-        'undocumented-isa-constraints' => '0.23',
-        'hashref-given-to-coerce'      => '0.24',
-    };
+    use List::Util 1.33 'any';
 
     sub _acquire_isa_tc { goto \&Moose::Util::TypeConstraints::find_or_create_isa_type_constraint }
 
@@ -88,11 +83,16 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
             predicate => 'has_original_isa',
         );
 
+        has trigger_method => (
+            is        => 'ro',
+            predicate => 'has_trigger_method',
+        );
+
         # TODO coerce via, transform ?
 
         # has original_isa, original_coerce ?
 
-        my $_process_options = sub {
+        method _mxas_process_options => sub {
             my ($class, $name, $options) = @_;
 
             my $_has = sub { defined $options->{$_[0]}             };
@@ -106,9 +106,6 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
             # handle: builder => 1, builder => sub { ... }
             $class->_mxas_builder($name, $options, $_has, $_opt, $_ref);
 
-            # handle: isa_class, isa_role, isa_enum
-            $class->_mxas_isa_naughty($name, $options, $_has, $_opt, $_ref);
-
             # handle: isa_instance_of => ...
             $class->_mxas_isa_instance_of($name, $options, $_has, $_opt, $_ref);
             # handle: isa => sub { ... }
@@ -138,7 +135,7 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
             ### set our other defaults, if requested...
             $default_for->($_) for qw{ predicate clearer };
             my $trigger = "$prefix{trigger}$name";
-            $options->{trigger} = sub { shift->$trigger(@_) }
+            do { $options->{trigger} = sub { shift->$trigger(@_) }; $options->{trigger_method} = $trigger }
                 if $options->{trigger} && $options->{trigger} eq '1';
 
             return;
@@ -149,7 +146,7 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
         # perspective -- and that we're potentially altering more than just
         # the 'is' option at one time.
 
-        before _process_options => $_process_options;
+        before _process_options => sub { shift->_mxas_process_options(@_) };
 
         # this feels... bad.  But I'm not sure there's any way to ensure we
         # process options on a clone/extends without wrapping new().
@@ -158,7 +155,7 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
             my ($orig, $self) = (shift, shift);
             my ($name, %options) = @_;
 
-            $self->$_process_options($name, \%options)
+            $self->_mxas_process_options($name, \%options)
                 if $options{__hack_no_process_options};
 
             return $self->$orig($name, %options);
@@ -203,30 +200,6 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
             return;
         };
 
-        # handle: isa_class, isa_role, isa_enum
-        method _mxas_isa_naughty => sub {
-            my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
-
-            return unless
-                any { exists $options->{$_} } qw{ isa_class isa_role isa_enum };
-
-            # (more than) fair warning...
-            deprecated(
-                feature => 'undocumented-isa-constraints',
-                message => 'Naughty! isa_class, isa_role, and isa_enum will be removed on or after 01 July 2015!',
-            );
-
-            # XXX undocumented -- not sure this is a great idea
-            $options->{isa} = class_type(delete $options->{isa_class})
-                if $_has->('isa_class');
-            $options->{isa} = role_type(delete $options->{isa_role})
-                if $_has->('isa_role');
-            $options->{isa} = enum(delete $options->{isa_enum})
-                if $_has->('isa_enum');
-
-            return;
-        };
-
         # handle: builder => 1, builder => sub { ... }
         method _mxas_builder => sub {
             my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
@@ -301,17 +274,6 @@ $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.028';
         method _mxas_coerce => sub {
             my ($class, $name, $options, $_has, $_opt, $_ref) = @_;
 
-            # "fix" the case of the hashref....  *sigh*
-            if ($_ref->('coerce') eq 'HASH') {
-
-                deprecated(
-                    feature => 'hashref-given-to-coerce',
-                    message => 'Passing a hashref to coerce is unsafe, and will be removed on or after 01 Jan 2015',
-                );
-
-                $options->{coerce} = [ %{ $options->{coerce} } ];
-            }
-
             if ($_ref->('coerce') eq 'ARRAY') {
 
                 ### must be type => sub { ... } pairs...
@@ -476,10 +438,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl David Graham Knop Steinbrunner GitHub attribute's isa one's rwp
-SUBTYPING foo
-
-=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
+=for :stopwords Chris Weyl Alders David Etheridge Graham Karen Knop Olaf Steinbrunner
+GitHub attribute's isa one's rwp SUBTYPING foo
 
 =head1 NAME
 
@@ -487,7 +447,7 @@ MooseX::AttributeShortcuts - Shorthand for common attribute options
 
 =head1 VERSION
 
-This document describes version 0.028 of MooseX::AttributeShortcuts - released April 07, 2015 as part of MooseX-AttributeShortcuts.
+This document describes version 0.029 of MooseX::AttributeShortcuts - released May 08, 2017 as part of MooseX-AttributeShortcuts.
 
 =head1 SYNOPSIS
 
@@ -540,6 +500,33 @@ This package causes an attribute trait to be applied to all attributes defined
 to the using class.  This trait extends the attribute option processing to
 handle the above variations.
 
+=head2 Some Notes On History
+
+Moose has long had a L<lazy_build attribute option|Moose/lazy_build>.  It was
+once considered a best practice, but that has, ah, changed.  This trait began
+as a desire to still leverage bits of C<lazy_build> (and a tacit
+acknowledgment that fat-finger bugs rank among the most embarrassing, right up
+there with "the TV was unplugged the entire time").
+
+This author does not recommend you use lazy_build, unless you know exactly
+what you're doing (probably) and that it's a good idea (probably not).
+
+Nonetheless, this C<lazy_build> option is why we set certain options the way
+we do below; while C<lazy_build> in its entirety is not optimal, it had the right
+idea: regular, predictable accessor names for regular, predictable attribute
+options.
+
+As an example, just looking at the below it doesn't seem logical that:
+
+    has _foo => (is => 'ro', clearer => 1);
+
+...becomes:
+
+    has _foo => (is => 'ro', clearer => '_clear_foo');
+
+After reading the L<lazy_build attribute option|Moose/lazy_build>,
+however, we see that the choice had already been made for us.
+
 =for Pod::Coverage init_meta
 
 =head1 USAGE
@@ -594,6 +581,8 @@ Specifying C<is =E<gt> 'rwp'> will cause the following options to be set:
     is     => 'ro'
     writer => "_set_$name"
 
+rwp can be read as "read + write private".
+
 =head2 is => 'lazy'
 
 Specifying C<is =E<gt> 'lazy'> will cause the following options to be set:
@@ -846,15 +835,10 @@ L<MooseX::Types|MooseX::Types>
 
 =back
 
-=head1 SOURCE
-
-The development version is on github at L<http://https://github.com/RsrchBoy/moosex-attributeshortcuts>
-and may be cloned from L<git://https://github.com/RsrchBoy/moosex-attributeshortcuts.git>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/moosex-attributeshortcuts/issues
+L<https://github.com/RsrchBoy/moosex-attributeshortcuts/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -864,28 +848,9 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head2 I'm a material boy in a material world
-
-=begin html
-
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
-<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
-<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-attributeshortcuts&title=RsrchBoy's%20CPAN%20MooseX-AttributeShortcuts&tags=%22RsrchBoy's%20MooseX-AttributeShortcuts%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
-
-=end html
-
-Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
-rather B<it is simply a very pleasant surprise>. I largely create and release
-works like this because I need them or I find it enjoyable; however, don't let
-that stop you if you feel like it ;)
-
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-attributeshortcuts&title=RsrchBoy's%20CPAN%20MooseX-AttributeShortcuts&tags=%22RsrchBoy's%20MooseX-AttributeShortcuts%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
-
 =head1 CONTRIBUTORS
 
-=for stopwords David Steinbrunner Graham Knop
+=for stopwords David Steinbrunner Graham Knop Karen Etheridge Olaf Alders
 
 =over 4
 
@@ -897,11 +862,19 @@ David Steinbrunner <dsteinbrunner@pobox.com>
 
 Graham Knop <haarg@haarg.org>
 
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Chris Weyl.
+This software is Copyright (c) 2017, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 
 This is free software, licensed under:
 
